==> dl.php?src=linea21_1_7.zip: linea21/languages/it/lang_search.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['search']['section'] = "ricerca";

$lang['search']['result'] = "Risultati della ricerca";
$lang['search']['keywords'] = "parola(e)-chiave(i) : ";
$lang['search']['method'] = "Metodo : ";
$lang['search']['min_length']='Gli elementi della vostra ricerca devono contenere più di 2 caratteri';
$lang['search']['query_time']='trattamento effettuato in';
$lang['search']['query_seconds']='secondi';
$lang['search']['no_result'] = "nessun risultato";
$lang['search']['score'] = "indice di pertinenza";
$lang['search']['score_abbr'] = "idp";
$lang['search']['score_not_good'] = "non affidabile";

$lang['search']['one_of_them'] = "una di queste parole";
$lang['search']['all_of_them'] = "l'insieme di queste parole";
$lang['search']['expression'] = "espressione compelta";
$lang['search']['text_button'] = "Lanciare la ricerca";

$lang['search']['comment_module'] = "Nei commenti";
$lang['search']['project_module'] = "Nei progetti";
$lang['search']['news_module'] = "Nelle news";
$lang['search']['page_module'] = "In pages"; // @todo translation
$lang['search']['newsletter_module'] = "Nelle newsletters";
$lang['search']['publication_module'] = "Nelle cartelle";
$lang['search']['det_publication_module'] = "Nelle sezioni delle cartelle";
$lang['search']['workshop_module'] = "Nei gruppi di lavoro";
$lang['search']['workshoprep_module'] = "Nei rapporti dei gruppi di lavoro";
$lang['search']['workshoprepcon_module'] = "Nelle sezioni dei rapporti dei gruppi di lavoro";
$lang['search']['workshopcal_module'] = "Nei calendari dei gruppi di valoro";
$lang['search']['workshopcom_module'] = "Nelle discussioni dei gruppi di lavoro";
$lang['search']['sdi_module'] = 'Negli indicatori';
$lang['search']['yellowpages_module'] = "Nella rubrica delle organizzazioni";
$lang['search']['user_module'] = "Tra gli utenti iscritti";
$lang['search']['theme_module'] = "Tra i temi";
$lang['search']['scale_module'] = "Nelle scale";
$lang['search']['level_module'] = "Nei livelli";

$lang['search']['help']="Motore di ricerca ".SITE_LINEA_NAME;
$lang['search']['help_list1']="Per effettuare una ricerca globale, clicca sull'icona \"lente di ingradimento\" o inserisci la tua parola chiave direttamente nella casella sotto il menù a sinistra";
$lang['search']['help_list2']="Per effettuare una recerca per rubriche, entra nella rubrica e clicca su \"ricerca\"";
$lang['search']['help_list3']="L'indice di pertinenza visualizzato è relativo ai documenti trovati dal motore : il documento più pertinente ha l'indice più elevato.";

?>

==> dl.php?src=linea21_1_8.zip: linea21/languages/it/lang_search.utf-8.php <==
<?php
/**
 * @package linea21\languages\it
 * @author $Author$ - Alessandra Rossi & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['search']['section'] = "ricerca";

$lang['search']['result'] = "Risultati della ricerca";
$lang['search']['keywords'] = "parola(e)-chiave(i) : ";
$lang['search']['method'] = "Metodo : ";
$lang['search']['min_length']='Gli elementi della vostra ricerca devono contenere più di 2 caratteri';
$lang['search']['query_time']='trattamento effettuato in';
$lang['search']['query_seconds']='secondi';
$lang['search']['no_result'] = "nessun risultato";
$lang['search']['score'] = "indice di pertinenza";
$lang['search']['score_abbr'] = "idp";
$lang['search']['score_not_good'] = "non affidabile";

$lang['search']['one_of_them'] = "una di queste parole";
$lang['search']['all_of_them'] = "l'insieme di queste parole";
$lang['search']['expression'] = "espressione compelta";
$lang['search']['text_button'] = "Lanciare la ricerca";

$lang['search']['comment_module'] = "Nei commenti";
$lang['search']['project_module'] = "Nei progetti";
$lang['search']['news_module'] = "Nelle news";
$lang['search']['page_module'] = "In pages"; // @todo translation
$lang['search']['newsletter_module'] = "Nelle newsletters";
$lang['search']['publication_module'] = "Nelle cartelle";
$lang['search']['det_publication_module'] = "Nelle sezioni delle cartelle";
$lang['search']['workshop_module'] = "Nei gruppi di lavoro";
$lang['search']['workshoprep_module'] = "Nei rapporti dei gruppi di lavoro";
$lang['search']['workshoprepcon_module'] = "Nelle sezioni dei rapporti dei gruppi di lavoro";
$lang['search']['workshopcal_module'] = "Nei calendari dei gruppi di valoro";
$lang['search']['workshopcom_module'] = "Nelle discussioni dei gruppi di lavoro";
$lang['search']['sdi_module'] = 'Negli indicatori';
$lang['search']['yellowpages_module'] = "Nella rubrica delle organizzazioni";
$lang['search']['user_module'] = "Tra gli utenti iscritti";
$lang['search']['theme_module'] = "Tra i temi";
$lang['search']['scale_module'] = "Nelle scale";
$lang['search']['tag_module'] = "Nei tags";

$lang['search']['help']="Motore di ricerca ".SITE_LINEA_NAME;
$lang['search']['help_list1']="Per effettuare una ricerca globale, clicca sull'icona \"lente di ingradimento\" o inserisci la tua parola chiave direttamente nella casella sotto il menù a sinistra";
$lang['search']['help_list2']="Per effettuare una recerca per rubriche, entra nella rubrica e clicca su \"ricerca\"";
$lang['search']['help_list3']="L'indice di pertinenza visualizzato è relativo ai documenti trovati dal motore : il documento più pertinente ha l'indice più elevato.";

?>
